@@ -22,11 +22,6 @@
 #' 	data(dems)
 #' 	mapplot(dems, ncol=4)
 #' 	
-#' 	#multiple variables
-#' 	data(clim)
-#' 	mapplot(clim, multi=TRUE, legend=TRUE)
-
-
 #' @rdname mapplot
 #' @exportMethod mapplot
 setGeneric("mapplot", function(x,...) standardGeneric("mapplot"))
@@ -412,14 +407,15 @@ setMethod("mapplot", signature="SpatialPolygons",
 
 
 
-#' Shorthand for the plotting \code{\link[chronosphere:RasterArray-class]{RasterArray}} objects
+#' Shorthand for the plotting \code{\link[chronosphere:RasterArray-class]{RasterArray}} and \code{\link[chronosphere:SpatialArray-class]{SpatialArray}} objects
 #' 
-#' This \code{plot}, method executes the \code{\link{mapplot}} function on the \code{\link[chronosphere:RasterArray-class]{RasterArray}} object.
+#' This \code{plot}, method executes the \code{\link{mapplot}} function on the \code{\link[chronosphere:RasterArray-class]{RasterArray}} or \code{\link[chronosphere:SpatialArray-class]{SpatialArray}}object.
 #' 
 #' @return None.
-#' @param x A (\code{\link[chronosphere:RasterArray-class]{RasterArray}}) Object to be plotted.
+#' @param x A (\code{\link[chronosphere:RasterArray-class]{RasterArray}} or \code{\link[chronosphere:SpatialArray-class]{SpatialArray}}) Object to be plotted.
 #' @param y Not implemented yet.
 #' @param ... Arguments passed to the \code{\link{mapplot}} function.
+#' @rdname plots
 #' @examples
 #' data(dems)
 #' plot(dems)
@@ -432,3 +428,16 @@ setMethod(
   }
 )
 
+
+#' @rdname plots
+#' @exportMethod plot
+setMethod(
+  "plot",
+  signature=c("SpatialArray", "missing"),
+  function(x,y, ...){
+    mapplot(x,...)
+  }
+)
+
+
+
